summaryrefslogtreecommitdiffstats
path: root/webkit/fileapi/sandbox_mount_point_provider.h
diff options
context:
space:
mode:
Diffstat (limited to 'webkit/fileapi/sandbox_mount_point_provider.h')
-rw-r--r--webkit/fileapi/sandbox_mount_point_provider.h12
1 files changed, 7 insertions, 5 deletions
diff --git a/webkit/fileapi/sandbox_mount_point_provider.h b/webkit/fileapi/sandbox_mount_point_provider.h
index be85f77..51a9414 100644
--- a/webkit/fileapi/sandbox_mount_point_provider.h
+++ b/webkit/fileapi/sandbox_mount_point_provider.h
@@ -6,6 +6,7 @@
#define WEBKIT_FILEAPI_SANDBOX_MOUNT_POINT_PROVIDER_H_
#include <string>
+#include <vector>
#include "base/file_path.h"
#include "googleurl/src/gurl.h"
@@ -28,8 +29,10 @@ class SandboxMountPointProvider : public FileSystemMountPointProvider {
const FilePath& profile_path);
virtual ~SandboxMountPointProvider();
- // Checks if mount point access is allowed from |origin_url|.
- virtual bool IsAccessAllowed(const GURL& origin_url);
+ // Checks if access to |virtual_path| is allowed from |origin_url|.
+ virtual bool IsAccessAllowed(const GURL& origin_url,
+ FileSystemType type,
+ const FilePath& virtual_path);
// Retrieves the root path for the given |origin_url| and |type|, and
// calls the given |callback| with the root path and name.
@@ -51,9 +54,6 @@ class SandboxMountPointProvider : public FileSystemMountPointProvider {
// The FileSystem directory name.
static const FilePath::CharType kFileSystemDirectory[];
- static const char kPersistentName[];
- static const char kTemporaryName[];
-
const FilePath& base_path() const {
return base_path_;
}
@@ -61,6 +61,8 @@ class SandboxMountPointProvider : public FileSystemMountPointProvider {
// Checks if a given |name| contains any restricted names/chars in it.
virtual bool IsRestrictedFileName(const FilePath& filename) const;
+ virtual std::vector<FilePath> GetRootDirectories() const;
+
// Returns the origin identifier string, which is used as a part of the
// sandboxed path component, for the given |url|.
static std::string GetOriginIdentifierFromURL(const GURL& url);